@@ -12,14 +12,18 @@ use Encode;
 
 has toUTF8 => sub { find_encoding('utf8') };
 
-our $VERSION = '0.908';
+our $VERSION = '1.0.2';
 
 has 'service';
 
 has 'crossDomain';
+
 has 'requestId';
+
 has 'methodName';
 
+has 'params';
+
 has log => sub { shift->app->log };
 
 sub dispatch {
@@ -97,7 +101,7 @@ sub dispatch {
     };
     $self->methodName($method);
 
-    my $params  = $data->{params} || []; # is a reference, so "unpack" it
+    $self->params($data->{params} // []);
  
     # invocation of method in class according to request 
     my $reply = eval {
@@ -132,7 +136,7 @@ sub dispatch {
              code=> 4
         } if not $self->can($method);
         if ($log->level eq 'debug'){
-            my $debug = encode_json($params);
+            my $debug = encode_json($self->params);
             if (not $ENV{MOJO_QX_FULL_RPC_DETAILS}){
                 if (length($debug) > 60){
                     $debug = substr($debug,0,60) . ' [...]';
@@ -142,7 +146,7 @@ sub dispatch {
         }
         # reply
         no strict 'refs';
-        return $self->$method(@$params);
+        return $self->$method(@$self->params);
     };
     if ($@){
         $self->renderJsonRpcError($@);
